Learn R Programming

PCovR (version 2.7.2)

psychiatrists: Effect of psychiatric symptoms on toxicomania, schizophrenia, depression and anxiety disorder

Description

The data contain the scores of 30 Belgian psychiatric patients on 23 psychiatric symptoms and 4 psychiatric disorders (toxicomania, schizophrenia, depression, and anxiety disorder). Each score is the sumscore of the binary symptom and disorder scores that were given by 15 different psychiatrists. The data can be used to examine the extent to which the degree of toxicomania, schizophrenia, depression and anxiety disorder, can be predicted by the 23 psychiatric symptoms.

Usage

data(psychiatrists)

Arguments

Format

The format is: List of 2

$ X:'data.frame': 30 obs. of 23 variables:

desorganised_speech

agitation

hallucinations

inappropriate

desorientation

depression

fear

suicide

somatic_concern

narcotics

antisocial

retardation

social_isolation

routine

alcohol

negativism

denial

grandeur

suspicion

intellectual_obstruction

impulse_control

social_leveling

occupational_dysfunction

$ Y:'data.frame': 30 obs. of 4 variables:

toxicomania

schizophrenia

depression

anxiety_disorder

References

Van Mechelen, I., & De Boeck, P. (1990). Projection of a binary criterion into a model of hierarchical classes. Psychometrika , 55 (4), 677-694.

Marlies Vervloet, Henk A. Kiers, Wim Van den Noortgate, Eva Ceulemans (2015). PCovR: An R Package for Principal Covariates Regression. Journal of Statistical Software, 65(8), 1-14. URL http://www.jstatsoft.org/v65/i08/.

Examples

Run this code
data(psychiatrists)
str(psychiatrists)

Run the code above in your browser using DataLab